==> haskell-implicit-hie-0.1.4.0-21-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-implicit-hie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 implicit-hie
version:              0.1.4.0
visibility:           public
id:                   implicit-hie-0.1.4.0-6oDYMpGOsw0rcIiRnijBz
key:                  implicit-hie-0.1.4.0-6oDYMpGOsw0rcIiRnijBz
license:              BSD-3-Clause
copyright:            2020
maintainer:           avi.the.coder@gmail.com
author:               Avi Dessauer
homepage:             https://github.com/Avi-D-coder/implicit-hie#readme
synopsis:             Auto generate hie-bios cradles & hie.yaml
description:
    Auto generate a stack or cabal multi component hie.yaml file

category:             Development, Tools, Hie, HLS
abi:                  5a34d4e115a70b7a4d01b96c9d48d1c4
exposed:              True
exposed-modules:      Hie.Cabal.Parser Hie.Locate Hie.Yaml
hidden-modules:       Paths_implicit_hie
import-dirs:          /usr/lib/ghc-9.4.8/site-local/implicit-hie-0.1.4.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/implicit-hie-0.1.4.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/implicit-hie-0.1.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-implicit-hie
hs-libraries:         HSimplicit-hie-0.1.4.0-6oDYMpGOsw0rcIiRnijBz
depends:
    attoparsec-0.14.4-BOYjI7Xnyxi2UxSSzbjWOG base-4.17.2.1
    directory-1.3.7.1 filepath-1.4.2.2
    filepattern-0.1.3-5Hyzo2Fno4k2qoDHkm5OdW text-2.0.2
    transformers-0.5.6.2 yaml-0.11.11.2-KMaHaCh4T6S1pXHm7ZoiOh

haddock-interfaces:
    /usr/share/doc/haskell-implicit-hie/html/implicit-hie.haddock

haddock-html:         /usr/share/doc/haskell-implicit-hie/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-implicit-hie-0.1.4.0-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-implicit-hie.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 implicit-hie
version:              0.1.4.0
visibility:           public
id:                   implicit-hie-0.1.4.0-GKDBVxhPg0t6LcyFbMi6Et
key:                  implicit-hie-0.1.4.0-GKDBVxhPg0t6LcyFbMi6Et
license:              BSD-3-Clause
copyright:            2020
maintainer:           avi.the.coder@gmail.com
author:               Avi Dessauer
homepage:             https://github.com/Avi-D-coder/implicit-hie#readme
synopsis:             Auto generate hie-bios cradles & hie.yaml
description:
    Auto generate a stack or cabal multi component hie.yaml file

category:             Development, Tools, Hie, HLS
abi:                  d34b743e7327d3f8cc7f4e49c6f3ea98
exposed:              True
exposed-modules:      Hie.Cabal.Parser Hie.Locate Hie.Yaml
hidden-modules:       Paths_implicit_hie
import-dirs:          /usr/lib/ghc-9.4.8/site-local/implicit-hie-0.1.4.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/implicit-hie-0.1.4.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/implicit-hie-0.1.4.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-implicit-hie
hs-libraries:         HSimplicit-hie-0.1.4.0-GKDBVxhPg0t6LcyFbMi6Et
depends:
    attoparsec-0.14.4-AfQEBsI4KfUBbsB9NxUVAd base-4.17.2.1
    directory-1.3.7.1 filepath-1.4.2.2
    filepattern-0.1.3-InddcU2oQJi3a2Bi8xDG4j text-2.0.2
    transformers-0.5.6.2 yaml-0.11.11.2-5s6yoQMtQtS4bHJ78lFa9u

haddock-interfaces:
    /usr/share/doc/haskell-implicit-hie/html/implicit-hie.haddock

haddock-html:         /usr/share/doc/haskell-implicit-hie/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
